==> moolticute-0.9.8_beta.tar.gz: moolticute-0.9.8-beta/src/TreeItem.h <==
#ifndef TREEITEM_H
#define TREEITEM_H

// Qt
#include <QList>
#include <QVariant>
#include <QVector>
#include <QDate>

class TreeItem
{
public:
    enum Status {USED=0, UNUSED};
    virtual ~TreeItem();

    const QString &name() const;
    void setName(const QString &sName);
    TreeItem *parentItem() const;
    void setParentItem(TreeItem *pParentItem);
    const Status &status() const;
    void setStatus(const Status &eStatus);
    const QDate &createdDate() const;
    void setCreatedDate(const QDate &dDate);
    const QDate &updatedDate() const;
    void setUpdatedDate(const QDate &dDate);
    const QString &description() const;
    void setDescription(const QString &sDescription);
    TreeItem *child(int iIndex);
    const QVector<TreeItem *> &childs() const;
    int childCount() const;
    int columnCount() const;
    TreeItem *parentItem();
    int row() const;
    virtual QVariant data(int iColumn) const;
    void addChild(TreeItem *pItem);
    bool removeOne(TreeItem *pItem);
    void clear();

protected:
    explicit TreeItem(const QString &sName = "",
                      const QDate &dCreatedDate = QDate::currentDate(),
                      const QDate &dUpdatedDate = QDate::currentDate(),
                      const QString &setDescription = "");

protected:
    QVector<TreeItem *> m_vChilds;
    TreeItem *m_pParentItem;
    Status m_eStatus;
    QString m_sName;
    QDate m_dCreatedDate;
    QDate m_dUpdatedDate;
    QString m_sDescription;
};

#endif // TREEITEM_H

==> moolticute-0.11.6_beta.tar.gz: moolticute-0.11.6-beta/src/TreeItem.h <==
#ifndef TREEITEM_H
#define TREEITEM_H

// Qt
#include <QList>
#include <QVariant>
#include <QVector>
#include <QDate>

class TreeItem
{
public:
    enum Status {USED=0, UNUSED};
    virtual ~TreeItem();

    const QString &name() const;
    void setName(const QString &sName);
    TreeItem *parentItem() const;
    void setParentItem(TreeItem *pParentItem);
    const Status &status() const;
    void setStatus(const Status &eStatus);
    const QDate &updatedDate() const;
    void setUpdatedDate(const QDate &dDate);
    const QDate &accessedDate() const;
    void setAccessedDate(const QDate &dDate);
    const QString &description() const;
    void setDescription(const QString &sDescription);
    TreeItem *child(int iIndex);
    const QVector<TreeItem *> &childs() const;
    int childCount() const;
    int columnCount() const;
    TreeItem *parentItem();
    int row() const;
    virtual QVariant data(int iColumn) const;
    void addChild(TreeItem *pItem);
    bool removeOne(TreeItem *pItem);
    void clear();

protected:
    explicit TreeItem(const QString &sName = "",
                      const QDate &dCreatedDate = QDate::currentDate(),
                      const QDate &dUpdatedDate = QDate::currentDate(),
                      const QString &setDescription = "");

protected:
    QVector<TreeItem *> m_vChilds;
    TreeItem *m_pParentItem;
    Status m_eStatus;
    QString m_sName;
    QDate m_dUpdatedDate;
    QDate m_dAccessedDate;
    QString m_sDescription;
};

#endif // TREEITEM_H
